# MeDaPy
**Me**asurement **Da**ta **Py**thon package

## Description
A Python package to work with measured data

## Installation

```bash
pip install medapy[OPTION]
```

where OPTION can be one of:
- `plot` - to use plot configs
- `fit` - for fitting capabilities
- `all` - includes all optional dependencies

### Requirements
Basic installation: `numpy, pandas, pint, pandas`

\[fit\]: `scipy, lmfit`

\[plot\]: `matplotlib`

## Examples
The files in `examples` folder should provide a basic familiarity with package capabilities

[Examples](./examples/)

## TODO
[TODO](todo.md)
